@@ -40,8 +40,8 @@ pub trait Hardware {
     /// Should the adapter not support this feature, [std::option::Option::None] is returned
     fn read_ignition_voltage(&mut self) -> Option<f32>;
 
-    /// Returns a list of hardware capabilities
-    fn get_capabilities(&self) -> &HardwareCapabilities;
+    /// Returns the information of the hardware
+    fn get_info(&self) -> &HardwareInfo;
 }
 
 #[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
@@ -49,8 +49,16 @@ pub trait Hardware {
 pub struct HardwareInfo {
     /// Name of the hardware
     pub name: String,
-    /// Vendor of the hardware
-    pub vendor: String,
+    /// Optional vendor of the hardware
+    pub vendor: Option<String>,
+    /// Optional version of the firmware running on the adapter / device
+    pub device_fw_version: Option<String>,
+    /// Optional API standard the device conforms to
+    pub api_version: Option<String>,
+    /// Optional library (Dll/So/Dynlib) verison used
+    pub library_version: Option<String>,
+    /// Optional file location of the library used
+    pub library_location: Option<String>,
     /// Listed capabilities of the hardware
     pub capabilities: HardwareCapabilities,
 }
