@@ -243,7 +243,11 @@ impl From<&PassthruInfo> for HardwareInfo {
     fn from(x: &PassthruInfo) -> Self {
         HardwareInfo {
             name: x.name.clone(),
-            vendor: x.vendor.clone(),
+            vendor: Some(x.vendor.clone()),
+            device_fw_version: None,
+            api_version: None,
+            library_version: None,
+            library_location: Some(x.function_lib.clone()),
             capabilities: HardwareCapabilities {
                 iso_tp: x.iso15765,
                 can: x.can,
@@ -272,12 +276,19 @@ impl PassthruDevice {
         let lib = info.function_lib.clone();
         let mut drv = lib_funcs::PassthruDrv::load_lib(lib)?;
         let idx = drv.open()?;
-        Ok(Self {
+        let mut ret = Self {
             info: info.into(),
             drv,
             device_idx: Some(idx),
             can_channel: false,
-        })
+        };
+        if let Ok(version) = ret.drv.get_version(idx) {
+            // Set new version information from the device!
+            ret.info.api_version = Some(version.api_version.clone());
+            ret.info.device_fw_version = Some(version.fw_version.clone());
+            ret.info.library_version = Some(version.dll_version.clone());
+        }
+        Ok(ret)
     }
 
     pub(crate) fn safe_passthru_op<
@@ -392,8 +403,8 @@ impl super::Hardware for PassthruDevice {
         }
     }
 
-    fn get_capabilities(&self) -> &super::HardwareCapabilities {
-        &self.info.capabilities
+    fn get_info(&self) -> &HardwareInfo {
+        &self.info
     }
 }
 
